**************************************************** 
****************************************************
** FIGURES FOR THE PAPER: "CORRUPTION AND FIRMS"
****************************************************
****************************************************

clear all 
set more off
set maxvar 30000
cap log close
set seed 1111


// Path: Write the path to the replication folder
	global path "~/Dropbox/Research/"	
	
// Subfolders
	global Data 	"${path}Data/"	
	global Tables 	"${path}Tables/"
	global Figures 	"${path}Figures/"
	
// Folder for tables
	cd "${Figures}"	

// Some codes to install
	*ssc install grstyle	
	
// Some options for figures
	grstyle init
	grstyle set plain	
	
********************************************************************************
** MAIN PAPER
********************************************************************************	

************	
// Figure 1. The Anti-Corruption Program Over Time
************
	* Load Dataset
	use "${Data}/Data_Yearly.dta", clear
	
	** Panel A: Audits
	preserve
		g Audited = 1
		collapse (mean) Audited, by(municipio year)
		collapse (sum) Audited, by(year)
		
		graph bar Audited, over(year, gap(15))  ///
			 ytitle("") bar(1, color(navy)) bargap(-10) 
		graph export "Figure_1A.pdf", replace as(pdf) 
		graph export "Figure_1A.eps", replace as(eps)		
	restore	
	
	** Panel B: Audited Amount
	preserve
		keep id year Totalamountreport_US
		duplicates drop
		collapse (sum) Totalamountreport_US, by(year)
		graph bar Totalamountreport_US, over(year, gap(15))  ///
			 ytitle("") bar(1, color(navy))
		
		graph export "Figure_1B.pdf", replace as(pdf) 
		graph export "Figure_1B.eps", replace as(eps)		
	restore	
			
	** Panel C: Mismanagement Irregularities
	preserve
		drop if year < 2006
		keep id year MismanagementIrreg CorruptionIrreg 
		duplicates drop
		collapse (sum) MismanagementIrreg , by(year)
		
		graph bar MismanagementIrreg, over(year, gap(15))  ///
			 ytitle("") bar(1, color(navy))

		graph export "Figure_1C.pdf", replace as(pdf) 
		graph export "Figure_1C.eps", replace as(eps)		
		
	restore
	
	** Panel D: Corruption Irregularities
	preserve
		drop if year < 2006
		keep id year  CorruptionIrreg
		duplicates drop
		collapse (sum) CorruptionIrreg, by(year)
		
		graph bar CorruptionIrreg, over(year, gap(15))  ///
			 ytitle("") bar(1, color(navy))

		graph export "Figure_1D.pdf", replace as(pdf) 
		graph export "Figure_1D.eps", replace as(eps)
	restore	
	

************	
// Figure 2. Corruption Across Brazilian Municipalities
************
	* Load Dataset
	use "${Data}/Data_Yearly.dta", clear
			
	local i "CorruptionIrreg_scaled"
	_pctile `i' if `i' > 0 & `i' != . , p(20(20)80)
				
	replace `i' = 0 if `i' == .
	forvalues dcl = 1/4 {
		local p`dcl' = r(r`dcl')
	}	
				 
	replace `i' = -2 if audited == 0
	replace `i' = -1 if ineligible == 1				
	sum	`i' if `i' != .
	local max = `r(max)'		

	spmap  `i' using "${Data}/Data_Yearly" , id(id_stata)  clmethod(custom) clb(-2 -1.5 -0.5 `p1' `p2' `p3' `p4' `max') ///
			fcolor(white red eltblue ebblue emidblue  edkblue dknavy ) osize(vthin ..)  ocolor(gs14 ..) ///
			legend(label(2 "Never Audited") label(3 "Ineligible") label(4 "Q1") label(5 "Q2") label(6 "Q3") label(7 "Q4") label(8 "Q5"))
	graph export "Figure_2.pdf" , replace as(pdf)
	graph export "Figure_2.eps" , replace as(eps)
		
************	
// Figure 3. Audits and Firms: Raw Data and Point Estimates
************
	
	** RAW DATA FIGURES
	* Load Dataset
	use "${Data}/Data_Quarterly.dta", clear
	
	levelsof TimeAudit, local(timeC)
	foreach y in `timeC' {
		preserve
			keep if TimeAudit == `y' | EverAuditedMunicipality != 1
			replace TimeAudit = `y' if YearAudited == .
			drop t
			g t = time - `y'
			keep nplants_priv nfirms_priv		///
				 TimeAudit TimeAudit municipio t EverAuditedMunicipality 
			
			tempfile t`y'
			save `t`y''.dta, replace		
		restore
	}	
	
	preserve
		use `t34'.dta, clear
		foreach y in `timeC' {
			append using `t`y''.dta
		}
		egen IDMun = group(municipio TimeAudit)
		duplicates drop
		tempfile main_q
		save `main_q'.dta, replace
	restore		
		
	use `main_q'.dta, clear
	
	keep if t >= -4 & t <= 12
	
	foreach i in nplants_priv nfirms_priv {											 
		bys IDMun: egen `i'_m = mean(`i') if t <= 0 		 
		spread `i'_m, by(IDMun)
		replace `i' = `i' / `i'_m
	}
	collapse  nplants_priv nfirms_priv	, by(EverAuditedMunicipality t)
				 
	foreach i in nplants_priv nfirms_priv {									
		g `i'_na = `i' if 	 EverAuditedMunicipality == 0 
		bys t: egen aux = mean(`i'_na)
		replace `i'_na = aux if `i'_na == .
		
		g d`i' = `i' - `i'_na
		drop aux
	}
		
	twoway (connected 	nplants_priv t if EverAuditedMunicipality == 1, lc(blue) mc(blue)) ///
			(connected 	nplants_priv t if EverAuditedMunicipality == 0, lc(gs12) mc(gs12) ), ///
			xtitle("Quarters since audit") ///
			ytitle("") ///				
			xline(0.5, lc(navy) ) ///	
			xlabel(-4(2)12) ///
			ylabel(, grid glcolor(ltbluishgray)) ///
			graphregion(color(white)) /// 
			legend(label(1 "Audited") label(2 "Control"))
													
	graph export "Figure_3A.pdf", replace as(pdf)
	graph export "Figure_3A.eps", replace as(eps)
					
	twoway (connected dnplants_priv t if EverAuditedMunicipality == 1, lc(blue) mc(blue)), ///
			xtitle("Quarters since audit") ///
			ytitle("") ///				
			xline(0.5, lc(navy) ) yline(0, lc(black)) ///				
			xlabel(-4(2)12) ///
			ylabel(-0.01(0.01)0.06, grid glcolor(ltbluishgray)) ///
			graphregion(color(white)) 
					
	graph export "Figure_3B.pdf", replace as(pdf)
	graph export "Figure_3B.eps", replace as(eps)
	
	twoway (connected 	nfirms_priv t if EverAuditedMunicipality == 1, lc(blue) mc(blue)) ///
			(connected 	nfirms_priv t if EverAuditedMunicipality == 0, lc(gs12) mc(gs12) ), ///
			xtitle("Quarters since audit") ///
			ytitle("") ///				
			xline(0.5, lc(navy) ) ///	
			xlabel(-4(2)12) ///
			ylabel(, grid glcolor(ltbluishgray)) ///
			graphregion(color(white)) /// 
			legend(label(1 "Audited") label(2 "Control"))
													
	graph export "Figure_3D.pdf", replace as(pdf)
	graph export "Figure_3D.eps", replace as(eps)
					
	twoway (connected dnfirms_priv t if EverAuditedMunicipality == 1, lc(blue) mc(blue)), ///
			xtitle("Quarters since audit") ///
			ytitle("") ///				
			xline(0.5, lc(navy) ) yline(0, lc(black)) ///				
			xlabel(-4(2)12) ///
			ylabel(-0.01(0.01)0.06, grid glcolor(ltbluishgray)) ///
			graphregion(color(white)) 
					
	graph export "Figure_3E.pdf", replace as(pdf)
	graph export "Figure_3E.eps", replace as(eps)	
					
	
	** POINT ESTIMATES FIGURES
	* Load Dataset
	use "${Data}/Data_Quarterly.dta", clear
	
	g d_4 = (t==-4)
	g d_3 = (t==-3)
	g d_2 = (t==-2)
	g d_1 = (t==-1)
	g d0 = (t==0)
	g d1 = (t==1)
	g d2 = (t==2)
	g d3 = (t==3)
	g d4 = (t==4)
	g d5 = (t==5)
	g d6 = (t==6)
	g d7 = (t==7)
	g d8 = (t==8)
	g d9 = (t==9)
	g d10 = (t==10)
	g d11 = (t==11)
	g d12 = (t==12)
	g d13 = (t==13)
	g d14 = (t==14)
	g d15 = (t==15)
	g d16 = (t==16)
	g d17 = (t==17)
	g d18 = (t==18)
	g d19 = (t==19)
	g d20 = (t==20)	
	replace d0 = 0 if EverAuditedMunicipality == 0
	
	rename ln_nplants_priv_w1 	Figure_3C
	rename ln_nfirms_priv_w1 	Figure_3F
	foreach j in Figure_3C Figure_3F {				
		local T "d_4 d_3 d_2 d_1 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12"
			reghdfe `j'  `T'  if year >= 2001 & t >= -4 & t <= 12, abs(municipio time ) cluster(municipio)	
			preserve
				estimate store coef 
							
				* Create data set of reg coefficients and confidence intervals 
				parmest, norestore

				* Keep parameters of interest
				drop if _n > 16			
				rename t tstat

				* Time variable from and since event
				drop t
									
				g       t = _n - 5 if _n <= 4
				replace t = _n - 4 if _n > 4								
								
				* Add coefficient in t == -1
				local tot = 1 + _N
				set obs `tot'
				replace t = 0 if _n == `tot'
				replace estimate = 0 if estimate == .
				replace min95 = 0 if min95 == .
				replace max95 = 0 if max95 == .
				sort t
							
				* Figure
				twoway (scatter estimate t, mc(navy)) (rcap min95 max95 t, lc(gs12) fc(gs12)), ///
					yline(0, lc(black) ) xline(0.5, lc(navy) lw(medium) ) ///
					graphregion(color(white)) /// 
					xlabel(-4(2)12) xtitle("Quarters since audit") ///
					graphregion(color(white)) /// 
					ylabel(-0.01(0.01)0.03, grid glcolor(ltbluishgray)) ///
					legend(off)

				* Export 			
				graph export "`j'.pdf", replace as(pdf)
				graph export "`j'.eps", replace as(eps)
			restore					
	}
	

************	
// Figure 4. Audits and Firms: Government-Dependent Sectors
************
	* Load Dataset
	use "${Data}/Data_Quarterly.dta", clear
	
	g d_4 = (t==-4)
	g d_3 = (t==-3)
	g d_2 = (t==-2)
	g d_1 = (t==-1)
	g d0 = (t==0)
	g d1 = (t==1)
	g d2 = (t==2)
	g d3 = (t==3)
	g d4 = (t==4)
	g d5 = (t==5)
	g d6 = (t==6)
	g d7 = (t==7)
	g d8 = (t==8)
	g d9 = (t==9)
	g d10 = (t==10)
	g d11 = (t==11)
	g d12 = (t==12)
	g d13 = (t==13)
	g d14 = (t==14)
	g d15 = (t==15)
	g d16 = (t==16)
	g d17 = (t==17)
	g d18 = (t==18)
	g d19 = (t==19)
	g d20 = (t==20)	
	replace d0 = 0 if EverAuditedMunicipality == 0
	
	rename ln_nplants_PSc4_e50pt1_w1 Figure_4A
	rename ln_nplants_PSc4_e50pt0_w1 Figure_4B
	rename ln_nplants_CSc4_50pNt1_w1 Figure_4C
	rename ln_nplants_CSc4_50pNt0_w1 Figure_4D

	rename ln_un_firms_PSc4_e50pt1_w1 Figure_4E 
	rename ln_un_firms_PSc4_e50pt0_w1 Figure_4F
	rename ln_un_firms_CSc4_50pNt1_w1 Figure_4G
	rename ln_un_firms_CSc4_50pNt0_w1 Figure_4H
	
	foreach j in Figure_4A Figure_4B Figure_4C Figure_4D Figure_4E Figure_4F Figure_4G Figure_4H {				
		local T "d_4 d_3 d_2 d_1 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12"
			reghdfe `j'  `T'  if year >= 2001 & t >= -4 & t <= 12, abs(municipio time ) cluster(municipio)	
			preserve
				estimate store coef 
							
				* Create data set of reg coefficients and confidence intervals 
				parmest, norestore

				* Keep parameters of interest
				drop if _n > 16			
				rename t tstat

				* Time variable from and since event
				drop t
									
				g       t = _n - 5 if _n <= 4
				replace t = _n - 4 if _n > 4								
								
				* Add coefficient in t == -1
				local tot = 1 + _N
				set obs `tot'
				replace t = 0 if _n == `tot'
				replace estimate = 0 if estimate == .
				replace min95 = 0 if min95 == .
				replace max95 = 0 if max95 == .
				sort t
							
				* Figure
				twoway (scatter estimate t, mc(navy)) (rcap min95 max95 t, lc(gs12) fc(gs12)), ///
					yline(0, lc(black) ) xline(0.5, lc(navy) lw(medium) ) ///
					graphregion(color(white)) /// 
					xlabel(-4(2)12) xtitle("Quarters since audit") ///
					graphregion(color(white)) /// 
					ylabel(-0.02(0.02)0.04, grid glcolor(ltbluishgray)) ///
					legend(off)

				* Export 			
				graph export "`j'.pdf", replace as(pdf)
				graph export "`j'.eps", replace as(eps)
			restore					
	}

	
